@@ -2,17 +2,14 @@
 
 global $blocked;
 
-$virusscan = 1;
-$virusscanupdate = 1;
-
 $excluded = Array('');
 
 $blocked = Array('bat',
-'com',
+'exe',
 'pif',
 'scr',
 'vbs');
 
-$warning = Array('exe');
+$warning = Array('com');
 
 ?>
\ No newline at end of file
