@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.4
+    Version ........ 0.5
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
@@ -22,11 +22,11 @@
    }
 
    function block_attach_display_option() {
-      include_once(SM_PATH . 'plugins/block_attach/includes/display_options.php');
+      include(SM_PATH . 'plugins/block_attach/includes/display_options.php');
    }
 
    function block_attach_version() {
-      return '0.4';
+      return '0.5';
    }
 
 ?>
\ No newline at end of file
